==> cscec5b-wzxt-api-3.0.1-20231129.101151-355-sources.jar: com/ejianc/business/wzxt/vo/CoordinationSetVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资参数设置
 * 
 * @author generator
 * 
 */
public class CoordinationSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 创建人名称
    private Integer specStatus; // 规格型号可以编辑 0-启用 1-停用
    private Long orgId; // 所属组织主键
    private String orgName; // 所属组织名称
    private String orgCode; // 所属组织编码
    private String orgInnerCode; // 组织内码
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Integer getSpecStatus() {
        return specStatus;
    }

    public void setSpecStatus(Integer specStatus) {
        this.specStatus = specStatus;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgInnerCode() {
        return orgInnerCode;
    }

    public void setOrgInnerCode(String orgInnerCode) {
        this.orgInnerCode = orgInnerCode;
    }
    
}

==> cscec5b-wzxt-api-3.0.1-20241219.030904-441-sources.jar: com/ejianc/business/wzxt/vo/CoordinationSetVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资参数设置
 *
 * @author generator
 *
 */
public class CoordinationSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String createUserName; // 创建人名称
    private Integer specStatus; // 规格型号可以编辑 0-启用 1-停用
    private Integer fjwzExitAddStatus; // 废旧物资是否可以直接新增和参照申请单做废旧出场 0-停用 1-启用
    private Long orgId; // 所属组织主键
    private String orgName; // 所属组织名称
    private String orgCode; // 所属组织编码
    private String orgInnerCode; // 组织内码


    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Integer getSpecStatus() {
        return specStatus;
    }

    public void setSpecStatus(Integer specStatus) {
        this.specStatus = specStatus;
    }

    public Integer getFjwzExitAddStatus() {
        return fjwzExitAddStatus;
    }

    public void setFjwzExitAddStatus(Integer fjwzExitAddStatus) {
        this.fjwzExitAddStatus = fjwzExitAddStatus;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgInnerCode() {
        return orgInnerCode;
    }

    public void setOrgInnerCode(String orgInnerCode) {
        this.orgInnerCode = orgInnerCode;
    }

}
